plot_extreme: plot_extreme

View source: R/plot_extreme.R

plot_extremeR Documentation

plot_extreme

Description

Graphs a line or bar plot of a row with the highest metric in a matrix, produced by daily_response or monthly_response functions. Bar plot is drawn for monthly_response(), while for daily_response, line plot is produced.

Usage

plot_extreme(
  result_daily_response,
  title = TRUE,
  ylimits = NULL,
  reference_window = "start",
  type = "daily",
  show_year_separators = TRUE
)

Arguments

result_daily_response

a list with objects as produced by daily_response or monthly_response function

title

logical, if set to FALSE, no plot title is displayed

ylimits

limit of the y axes. It should be given as ylimits = c(0,1)

reference_window

character string, the reference_window argument describes, how each calculation is referred. There are three different options: 'start' (default), 'end' and 'middle'. If available, the value stored in result_daily_response$reference_window is used.

type

the character string describing type of analysis: daily or monthly

show_year_separators

logical. If TRUE, dashed vertical lines are added between relative-year blocks. The default is TRUE.

Value

A ggplot2 object containing the plot display


dendroTools documentation built on May 21, 2026, 1:06 a.m.