plot_heatmap: plot_heatmap

View source: R/plot_heatmap.R

plot_heatmapR Documentation

plot_heatmap

Description

Graphs a heatmap of values stored in a matrix, such as produced by daily_response or monthly_response functions.

Usage

plot_heatmap(
  result_daily_response,
  reference_window = "start",
  type = "daily",
  show_title = FALSE,
  show_year_separators = TRUE
)

Arguments

result_daily_response

a list with objects as produced by daily_response, monthly_response, daily_response_seascorr or monthly_response_seascorr.

reference_window

character string, the reference_window argument describes how each calculation is referred. Options are 'start', 'end' and 'middle'. If available, the value stored in result_daily_response$reference_window is used.

type

the character string describing type of analysis: daily or monthly.

show_title

logical. If TRUE, the plot title with analysed period, method and reference-window information is shown. The default is FALSE.

show_year_separators

logical. If TRUE, dashed vertical lines are added between relative-year blocks in plots with previous-year data. The default is TRUE.

Value

A ggplot2 object containing the heatmap display


dendroTools documentation built on May 21, 2026, 1:06 a.m.