| plot_heatmap | R Documentation |
Graphs a heatmap of values stored in a matrix, such as produced
by daily_response or monthly_response functions.
plot_heatmap(
result_daily_response,
reference_window = "start",
type = "daily",
show_title = FALSE,
show_year_separators = TRUE
)
result_daily_response |
a list with objects as produced by
|
reference_window |
character string, the reference_window argument describes how each calculation is referred. Options are 'start', 'end' and 'middle'. If available, the value stored in result_daily_response$reference_window is used. |
type |
the character string describing type of analysis: daily or monthly. |
show_title |
logical. If TRUE, the plot title with analysed period, method and reference-window information is shown. The default is FALSE. |
show_year_separators |
logical. If TRUE, dashed vertical lines are added between relative-year blocks in plots with previous-year data. The default is TRUE. |
A ggplot2 object containing the heatmap display
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.